@@ -5,7 +5,7 @@
 #################################################################
 
 ##Author: Christos Zamantzas <christos.zamantzas@gmail.com>
-##Version: 0.2.0-3
+##Version: 0.3-0
 
 import os
 import sys
@@ -20,6 +20,7 @@ from swappolubeUI import *
 ##############################################################
 
 Path         = '/home/user/.swappolube/'      # temp path of files
+AppPath      = '/opt/swappolube/'             # application path
 ConfigFile   = 'swappolube_config_temp'       # name of temp config file
 DefaultFile  = 'swappolube_config_default'    # name of default config file
 MainPath     = '/etc/event.d/'                # main path
@@ -70,7 +71,7 @@ def doUpdateConfig():
 
     time.sleep(1)
     try:
-       os.system('echo "cp %s %s"|root' % (Path + ConfigFile, MainPath + MainFile))
+       os.system('cp %s %s' % (Path + ConfigFile, MainPath + MainFile))
     except:
        return False
     else: 
@@ -118,7 +119,7 @@ class MyMainWindow(QtGui.QMainWindow):
              QMessageBox.about(self, "Credits - SWAPPOLUBE Editor", msg)
  
         def doDeleteTunings(self): ##FIXME: check if file was deleted!!
-             os.system('echo "rm /etc/event.d/tuning"|root')
+             os.system('rm /etc/event.d/tuning')
              message = 'The tuning file has been removed from the boot sequence.\nOn next reboot, the system will start with its default configuration.'
              showMessage(message)
 
@@ -242,28 +243,27 @@ class MyMainWindow(QtGui.QMainWindow):
               
              ##Update the values.
              if self.ui.radioKillAllocatingTask.isChecked() == True:
-               os.system('echo "echo \"%s\" > /proc/sys/vm/oom_kill_allocating_task"|root' % KillAllocatingTask) 
+               os.system('sudo %supdateTuning KillAllocatingTask %s' % (AppPath, KillAllocatingTask) )
              if self.ui.radioPageCluster.isChecked() == True:
-               os.system('echo "echo \"%s\" > /proc/sys/vm/page-cluster"|root' % PageCluster) 
+               os.system('sudo %supdateTuning PageCluster %s' % (AppPath, PageCluster) )
              if self.ui.radioLaptopMode.isChecked() == True:
-               os.system('echo "echo \"%s\" > /proc/sys/vm/laptop_mode"|root' % LaptopMode) 
+               os.system('sudo %supdateTuning LaptopMode %s' % (AppPath, LaptopMode) )
              if self.ui.radioDirtyExpireCentisecs.isChecked() == True:
-               os.system('echo "echo \"%s\" > /proc/sys/vm/dirty_expire_centisecs"|root' % DirtyExpireCentisecs) 
+               os.system('sudo %supdateTuning DirtyExpireCentisecs %s' % (AppPath, DirtyExpireCentisecs) )
              if self.ui.radioTCPTimestamps.isChecked() == True:
-               os.system('echo "echo \"%s\" > /proc/sys/net/ipv4/tcp_timestamps"|root' % TCPTimestamps) 
+               os.system('sudo %supdateTuning TCPTimestamps %s' % (AppPath, TCPTimestamps) )
              if self.ui.radioDirtyWritebackCentisecs.isChecked() == True:
-               os.system('echo "echo \"%s\" > /proc/sys/vm/dirty_writeback_centisecs"|root' % DirtyWritebackCentisecs) 
+               os.system('sudo %supdateTuning DirtyWritebackCentisecs %s' % (AppPath, DirtyWritebackCentisecs) )
              if self.ui.radioTCPNoMetricsSave.isChecked() == True:
-               os.system('echo "echo \"%s\" > /proc/sys/net/ipv4/tcp_no_metrics_save"|root' % TCPNoMetricsSave) 
+               os.system('sudo %supdateTuning TCPNoMetricsSave %s' % (AppPath, TCPNoMetricsSave) )
              if self.ui.radioDirtyRatio.isChecked() == True:
-               os.system('echo "echo \"%s\" > /proc/sys/vm/dirty_ratio"|root' % DirtyRatio) 
+               os.system('sudo %supdateTuning DirtyRatio %s' % (AppPath, DirtyRatio) )
              if self.ui.radioSwappiness.isChecked() == True:
-               os.system('echo "echo \"%s\" > /proc/sys/vm/swappiness"|root' % Swappiness) 
+               os.system('sudo %supdateTuning Swappiness %s' % (AppPath, Swappiness) )
              if self.ui.radioDirtyBGDRatio.isChecked() == True:
-               os.system('echo "echo \"%s\" > /proc/sys/vm/dirty_background_ratio"|root' % DirtyBGDRatio) 
+               os.system('sudo %supdateTuning DirtyBGDRatio %s' % (AppPath, DirtyBGDRatio) )
              if self.ui.radioVFSCachePressure.isChecked() == True:
-               os.system('echo "echo \"%s\" > /proc/sys/vm/vfs_cache_pressure"|root' % VFSCachePressure) 
-
+               os.system('sudo %supdateTuning VFSCachePressure %s' % (AppPath, VFSCachePressure) )
              message = 'The new configuration has been applied to the system.'
              showMessage(message)
              
@@ -358,7 +358,7 @@ if __name__ == "__main__":
         
           ##Check with what priviledges the GUI has been executed
           if os.geteuid() == 0:
-             message ='ERROR: The swappolube editor should not be executed as root. Exiting..'
+             message ='ERROR: The swappolube editor cannot be executed as root. Exiting..'
              showMessage(message)
              sys.exit(1)
           
